@@ -39,9 +39,9 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 function setFirstStart() {
   const firststart = document.getElementById("chb_firststart");
   if (firststart.checked) {
-      localStorage.setItem("ReadFirstStart", true);
+      saveToLocalStorage("ReadFirstStart", true);
   } else {
-      localStorage.setItem("ReadFirstStart", false);
+      saveToLocalStorage("ReadFirstStart", false);
   }
 }
 
@@ -54,9 +54,9 @@ function setFirstStart() {
 * @param {string} mode - This is the view mode you want to switch to.
 */
 function ToggleViewMode(mode) {
-  localStorage.setItem("viewmode", mode);
+  saveToLocalStorage("viewmode", mode);
 
-  if (localStorage.getItem("viewmode") === "basic") {
+  if (getFromLocalStorage("viewmode") === "basic") {
     //   document.getElementById("ModeBasic").classList.add("link_focus");
     //   document.getElementById("ModeAdvanced").classList.remove("link_focus");
       for (
@@ -65,7 +65,7 @@ function ToggleViewMode(mode) {
           const element = document.getElementsByClassName("adba")[index];
           element.classList.add("basicview");
       }
-  } else if (localStorage.getItem("viewmode") === "advanced") {
+  } else if (getFromLocalStorage("viewmode") === "advanced") {
     //   document.getElementById("ModeBasic").classList.remove("link_focus");
     //   document.getElementById("ModeAdvanced").classList.add("link_focus");
       for (
@@ -85,21 +85,21 @@ function setFirstSatteldruckanalyse() {
       "chb_firstSatteldruckanalyse"
   );
   if (firstSatteldruckanalyse.checked) {
-      localStorage.setItem("ReadFirstSatteldruckanalyse", true);
+      saveToLocalStorage("ReadFirstSatteldruckanalyse", true);
   } else {
-      localStorage.setItem("ReadFirstSatteldruckanalyse", false);
+      saveToLocalStorage("ReadFirstSatteldruckanalyse", false);
   }
 }
 
 
 var custommask = 
- [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
-  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
-  0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0,
-  0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0,
+ [0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0,
   0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0,
   0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0,
   0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0,
+  0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0,
+  0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0,
+  0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0,
   0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0,
   0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0,
   0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0,
@@ -122,45 +122,82 @@ var custommask =
   0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
   0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
 ];
-/* This code block checks if there is an element with the class name 'live' in the document. If such an
-element exists, it creates a grid of div elements and appends them to the 'live' element. Each div
-element has a unique id based on its position in the grid (calculated using the variables i and j),
-and an onclick attribute that calls the function `toogleMaskpoint()` with the corresponding i, j,
-and id values. The div elements also have the class 'a' added to them. Finally, the function `tM()`
-is called for each div element to set its background color based on the value in the custommask
-array. */
-if (document.getElementsByClassName('live')[0])
-  for (let i = 0; i < 28; i++) {
-      for (let j = 0; j < 16; j++) {
-          let id = i * 16 + j;
-          let x = document.createElement('div');
-          x.setAttribute("onclick", `toogleMaskpoint(${i},${j},${id})`)
-          x.id = "Mp" + id
-          x.classList.add("a");
-          document.getElementsByClassName('live')[0].append(x);
-          tM(i, j, id)
+
+liveMask();
+frame3Mask();
+
+/**
+ * The function `liveMask` dynamically creates and initializes mask points within a grid structure for
+ * a live editing feature.
+ */
+function liveMask(){
+    if (document.getElementsByClassName('live')[0])
+        for (let i = 0; i < 28; i++) {
+            for (let j = 0; j < 16; j++) {
+                let id = i * 16 + j;
+                let x = document.createElement('div');
+                x.setAttribute("onchange", `toogleMaskpoint(${i},${j},${id})`)
+                x.id = "Mp" + id
+                x.classList.add("a");
+                document.getElementsByClassName('live')[0].append(x);
+                tM(i, j, id)
+            }
+        }
+}
+
+/**
+ * The function `frame3Mask` creates a grid layout with rows and columns, each containing a div element
+ * with specific classes and attributes.
+ */
+//function frame3Mask(){
+//    if (document.getElementsByClassName('Frame-3')[0])
+//        for (let i = 0; i < 28; i++) {
+//            let e = document.createElement('div');
+//            e.classList.add("row" + i, "line")
+//            document.getElementsByClassName('Frame-3')[0].append(e);
+//            for (let j = 0; j < 16; j++) {
+//                let id = i * 16 + j;
+//                let x = document.createElement('div');
+//                x.setAttribute("onchange", `toogleMaskpoint(${i},${j},${id})`)
+//                x.id = "Mp" + id
+//                x.classList.add("grid_a")
+//                x.classList.add("a");
+//                document.getElementsByClassName('row' + i)[0].append(x);
+//                tM(i, j, id)
+      
+//            }
+//        }
+//}
+
+function frame3Mask() {
+  // Übergeordnetes Div erstellen
+  if (document.getElementsByClassName('Frame-3')[0]) {
+    let maskGrid = document.createElement('div');
+    maskGrid.id = 'mask_grid';
+    document.getElementsByClassName('Frame-3')[0].append(maskGrid);
+      for (let i = 0; i < 28; i++) {
+          let e = document.createElement('div');
+          e.classList.add("row" + i, "line");
+          // Zeilen-Div an das übergeordnete Div anhängen
+          maskGrid.append(e);
+
+          for (let j = 0; j < 16; j++) {
+              let id = i * 16 + j;
+              let x = document.createElement('div');
+              x.setAttribute("onchange", `toogleMaskpoint(${i},${j},${id})`);
+              x.id = "Mp" + id;
+              x.classList.add("grid_a");
+              x.classList.add("a");
+              document.getElementsByClassName('row' + i)[0].append(x);
+              tM(i, j, id);
+          }
       }
   }
+}
 
 /* This code block is checking if there is an element with the class name 'Frame-3' in the document. If
 such an element exists, it creates a grid of div elements and appends them to the 'Frame-3' element. */
-if (document.getElementsByClassName('Frame-3')[0])
-  for (let i = 0; i < 28; i++) {
-      let e = document.createElement('div');
-      e.classList.add("row" + i, "line")
-      document.getElementsByClassName('Frame-3')[0].append(e);
-      for (let j = 0; j < 16; j++) {
-          let id = i * 16 + j;
-          let x = document.createElement('div');
-          x.setAttribute("onclick", `toogleMaskpoint(${i},${j},${id})`)
-          x.id = "Mp" + id
-          x.classList.add("grid_a")
-          x.classList.add("a");
-          document.getElementsByClassName('row' + i)[0].append(x);
-          tM(i, j, id)
 
-      }
-  }
 
 /**
 * It takes the contents of the custommask array and sends it to the server
@@ -192,6 +229,11 @@ function sendMask() {
  * @param name - The name of the mask to be saved.
  */
 function saveMask(name) {
+
+    let checkbox = document.getElementById('maskedit')
+    checkbox.checked = false
+    //checkbox.nextSibling.classList.remove('custom_switch')
+
     name=name.replaceAll(" ","");
     name=name.replace("10","X");
     name=name.replace("1","I");
@@ -235,7 +277,7 @@ function toogleMaskpoint(i, j, idx) {
       sendMask()
   } else {
       custommask[idx] = 1;
-      document.getElementById(id).style.backgroundColor = '#e50e0e52'
+      document.getElementById(id).style.backgroundColor = '#d79292'//'#e50e0e52'
       sendMask()
   }
 }
@@ -256,7 +298,58 @@ function tM(i, j, idx) {
       document.getElementById(id).style.backgroundColor = 'rgb(255 255 255 / 0%)'
   } else {
       custommask[idx] = 1;
-      document.getElementById(id).style.backgroundColor = '#e50e0e52'
+      document.getElementById(id).style.backgroundColor = '#d79292'//'#e50e0e52'
   }
 }
 
+let isMouseDown = false; // Verfolgt, ob die Maustaste gedrückt ist
+let lastToggledElement = null; // Verfolgt das zuletzt getogglete Element
+
+// Event listener für den Anfang des Klickens (Mouse Down)
+document.addEventListener('mousedown', (event) => {
+  const element = event.target;
+  if (element.classList.contains('grid_a')) {
+    isMouseDown = true;
+    lastToggledElement = element; // Setzt das aktuelle Element als das zuletzt getogglete
+    toggleElement(element); // Toggle das erste Element
+    event.preventDefault(); // Verhindert unerwünschtes Selektieren von Text
+  }
+});
+
+// Event listener für das Bewegen der Maus (Mouse Move) während des Klickens
+document.addEventListener('mousemove', (event) => {
+  if (isMouseDown) {
+    const element = document.elementFromPoint(event.clientX, event.clientY); // Ermittelt das Element unter der Maus
+    if (element && element.classList.contains('grid_a') && element !== lastToggledElement) {
+      toggleElement(element); // Toggle das Element nur, wenn es sich um ein neues handelt
+      lastToggledElement = element; // Aktualisiert das zuletzt getogglete Element
+    }
+  }
+});
+
+// Event listener für das Loslassen der Maustaste (Mouse Up)
+document.addEventListener('mouseup', () => {
+  isMouseDown = false; // Setzt den Zustand "Maustaste nicht mehr gedrückt"
+  lastToggledElement = null; // Setzt das zuletzt getogglete Element zurück
+});
+
+// Hilfsfunktion, um ein Element umzuschalten
+function toggleElement(element) {
+  const [row, col, id] = getMaskPointFromElement(element);
+  toogleMaskpoint(row, col, id);
+}
+
+// Funktion, um aus dem Element die Reihen- und Spaltenwerte zu extrahieren
+function getMaskPointFromElement(element) {
+  const onclickAttr = element.getAttribute('onchange');
+  const regex = /toogleMaskpoint\((\d+),(\d+),(\d+)\)/;
+  const match = onclickAttr.match(regex);
+  if (match) {
+    const row = parseInt(match[1], 10);
+    const col = parseInt(match[2], 10);
+    const id = parseInt(match[3], 10);
+    return [row, col, id];
+  }
+  return [];
+}
+
