@@ -44,7 +44,16 @@ Nname.innerHTML =  client_surename;
 Vname.innerHTML =  client_forenames;
 Email.innerHTML =  client_mail;
 document.getElementById('pi_id').innerHTML = client_id;
-document.getElementById('pi_fc').innerHTML = client_fc.split(' ')[0];
+//document.getElementById('pi_fc').innerHTML = client_fc.split(' ')[0];
+let fcDate = client_fc.split(' ')[0]; // "2025-10-23"
+var lang = localStorage.getItem('lang');
+
+if (lang === 'de') {
+  const [year, month, day] = fcDate.split('-');
+  fcDate = `${day}.${month}.${year}`;
+}
+
+document.getElementById('pi_fc').innerHTML = fcDate;
 
 /* The `newElement` function is being called with several arguments to create a new HTML element and
 append it to the element with the ID `pi_newSession`. */
@@ -59,40 +68,53 @@ gen_session_list()
  */
 function gen_session_list() {
     let into = document.getElementById('pi_sl');
-    let head = ['Session','Datum','info','']
-    let table = document.createElement('table')
-    table.classList.add('uk-table', 'uk-table-hover', 'uk-table-divider')
-    into.append(table)
+    let head = ['Session','Datum','info',''];
+    let lang = localStorage.getItem('lang');
+
+    let table = document.createElement('table');
+    table.classList.add('uk-table', 'uk-table-hover', 'uk-table-divider');
+    into.append(table);
+
     let thead = document.createElement('thead');
-    table.append(thead)
+    table.append(thead);
     let tr_head = document.createElement('tr');
     thead.append(tr_head);
-    head.forEach(e=>{
+    head.forEach(e => {
         let th_head = document.createElement('th');
         th_head.innerHTML = e;
-        th_head.setAttribute('key',`cli_tablehead_${e}`)
+        th_head.setAttribute('key', `cli_tablehead_${e}`);
         tr_head.append(th_head);
-    })
+    });
+
     let tbody = document.createElement('tbody');
     table.append(tbody);
 
     client_info.forEach(e => {
-        var tr_body = document.createElement('tr');
-        tr_body.classList.add('suche')
-        tr_body.setAttribute('suche',`${e.notes||""} ${e.date} ${e.session_id}`)
-        // tr_body.setAttribute('uk-tooltip',`${aLangKeys[lang]['tooltip_session_retrive']}`)
-        tr_body.classList.add('cur_pointer')
-        tr_body.id = `cli_${e.session_id}`
-        // tr_body.setAttribute('onclick',`rest_session(${e.session_id})`)
+        // --- Datum umformatieren falls Sprache 'de' ---
+        let date = e.date || '';
+        if (lang === 'de' && date) {
+            const parts = date.split(' ');
+            const d = parts[0].split('-'); // [YYYY,MM,DD]
+            if (d.length === 3) {
+                date = `${d[2]}.${d[1]}.${d[0]}`;
+            }
+            if (parts[1]) date += ' ' + parts[1]; // Zeit anhängen, falls vorhanden
+        }
+
+        let tr_body = document.createElement('tr');
+        tr_body.classList.add('suche', 'cur_pointer');
+        tr_body.setAttribute('suche', `${e.notes || ""} ${e.date} ${e.session_id}`);
+        tr_body.id = `cli_${e.session_id}`;
         tbody.append(tr_body);
-        tr_body.innerHTML  = `<td onclick='session_img(${e.session_id},"${e.notes||""}")'>${e.session_id}</td>`;
-        tr_body.innerHTML += `<td onclick='session_img(${e.session_id},"${e.notes||""}")'>${e.date}</td>`;
-        tr_body.innerHTML += `<td onclick='session_img(${e.session_id},"${e.notes||""}")'>${e.notes||""}</td>`;
-        // tr_body.innerHTML += `<td><button class="uk-button uk-button-default uk-button-small" onclick="toProtokoll(${e.session_id})" uk-icon="icon: copy"></button></td>`;
-        tr_body.innerHTML += `<td><button class="ico-16 mdi mdi-trash-can-outline uk-button uk-button-default uk-button-small adba basicview" onclick="SessionDel(${e.session_id})"></button></td>`
+
+        tr_body.innerHTML  = `<td onclick='session_img(${e.session_id},"${e.notes || ""}")'>${e.session_id}</td>`;
+        tr_body.innerHTML += `<td onclick='session_img(${e.session_id},"${e.notes || ""}")'>${date}</td>`;
+        tr_body.innerHTML += `<td onclick='session_img(${e.session_id},"${e.notes || ""}")'>${e.notes || ""}</td>`;
+        tr_body.innerHTML += `<td><button class="ico-16 mdi mdi-trash-can-outline uk-button uk-button-default uk-button-small adba basicview" onclick="SessionDel(${e.session_id})"></button></td>`;
     });
+
     ToggleViewMode(getFromLocalStorage("viewmode"));
-    translatejs()    
+    translatejs();
 }
 
 /**
