@@ -68,6 +68,22 @@ function browser(){
   
 }
 
+function checkBrowser() {
+  let userAgent = navigator.userAgent;
+
+  // Prüfen, ob es sich um Chrome handelt (und nicht Edge, da dieser auch "Chrome" im User-Agent enthält)
+  let isChrome = /Chrome/.test(userAgent) && !/Edg/.test(userAgent) && !/OPR/.test(userAgent);
+
+  if (!isChrome) {
+      // Modal öffnen, wenn kein Chrome genutzt wird
+      OpenModalEX('mod_browser_check_full');
+      //UIkit.modal('#mod_browser_check').show();
+  }
+}
+
+// Funktion beim Laden der Seite ausführen
+document.addEventListener("DOMContentLoaded", checkBrowser);
+
 
 
 function noHocker() {
