@@ -63,6 +63,15 @@ let sda_frame3 = `${host}/sattelbild?image=blank`;
 _name();
 _satteldruckanalyse();
 
+
+var Protokolldate = new Date().toISOString().split('T')[0]; // "2025-10-23"
+var lang = localStorage.getItem('lang');
+
+if (lang === 'de') {
+  const [year, month, day] = Protokolldate.split('-');
+  Protokolldate = `${day}.${month}.${year}`;
+}
+
 /**
  * It gets the name from local storage and puts it in the right places
  */
@@ -167,13 +176,8 @@ sattelanalyse.onmessage = (e) => {
      </ul>
      <textarea id="info_${recID[fi - 1]}" readonly class="uk-textarea" style="width:180px;height: 60px;margin-left:40px ">${galerie_image_info.notes}</textarea>`;
     document.getElementsByClassName("name_img")[fi - 1].innerHTML = `
-     <h2 id="label_${recID[fi-1]}" class="uk-text-center">${
-       galerie_image_info.product_label || "(no Typ)"
-     }</h2>
-     <p class="uk-text-center"><small id="marke_${recID[fi-1]}">${
-       galerie_image_info.product ||
-       "(no " + aLangKeys[lang]["pro_satteldruck_marke"] + ")"
-     }</small></p>`;
+     <h2 class="uk-text-center" id="marke_${recID[fi-1]}">${galerie_image_info.product ||`(no ${aLangKeys[lang]["pro_satteldruck_marke"]})`}</h2>
+     <p id="label_${recID[fi-1]}" class="uk-text-center">${galerie_image_info.product_label || "(no Typ)"}</p>`;
     if (recID[fi]) {
       console.log("sda_init3 send");
       sattelanalyse.send(`recording retrieve ${recID[fi]}`);
@@ -319,13 +323,22 @@ function RowImg(params) {
     master.append(div);
 
     let del = document.createElement("div");
-    del.classList.add("adba","del_img", "mdi", "mdi-trash-can-outline");
+    //del.classList.add("adba","del_img", "mdi", "mdi-trash-can-outline");
+    del.classList.add("del_img", "mdi", "mdi-trash-can-outline");
     del.setAttribute("onclick", `openDelDialog(${element.recording_id})`);
     master.append(del);
 
+    let dateValue = element.finished; // z. B. "2025-10-23 14:22:00"
+    let [datePart, timePart] = dateValue.split(' '); // ["2025-10-23", "14:22:00"]
+
+    if (lang === 'de') {
+      const [year, month, day] = datePart.split('-');
+      datePart = `${day}.${month}.${year}`;
+    }
+
     let date = document.createElement("p");
     date.classList.add("uk-text-center");
-    date.innerHTML = element.finished;
+    date.innerHTML = `${datePart} ${timePart}`;
     master.append(date);
 
     let div_name = document.createElement("div");
@@ -418,7 +431,7 @@ function PDFgenGal(){
   if(getFromLocalStorage('session_note') !== ''){
     content.push({text:`${getFromLocalStorage('session_note')}`, style: ['bigger','bold','center']})   
   }
-  content.push({text:`${new Date().toISOString().split('T')[0]}`,style:['small','center']})
+  content.push({text:`${Protokolldate}`,style:['small','center']})
   content.push('\n')
     //content.push({text:`${text}`})
     content.push('\n')
@@ -476,8 +489,8 @@ function PDFgenGal(){
 
             //content.push({ qr: `${script_setting.UserWeb}`,fit:50,style:'center' })
             let y = new Object();
-            y.text =  `${document.getElementById(`label_${i.id}`).innerHTML}\n`
-            y.text += `${document.getElementById(`marke_${i.id}`).innerHTML}\n`
+            y.text =  `${document.getElementById(`marke_${i.id}`).innerHTML}\n`
+            y.text += `${document.getElementById(`label_${i.id}`).innerHTML}\n`
             y.text += '\n'
             y.text += `${aLangKeys[lang]['pro_satteldruck_veloscore']}: ${document.getElementById(`veloscore_${i.id}`).innerHTML}\n`
             y.text += `${aLangKeys[lang]['pro_satteldruck_becken']}: ${document.getElementById(`becken_${i.id}`).innerHTML}\n`
@@ -625,7 +638,8 @@ function PDFgenGal(){
           //  { text:"",style:['right'],margin:[40,0]},
             { text:`Bike Fitter: ${name2}`,style:['right','XXS'],margin:[40,0]},
             { text:`${getFromLocalStorage('client_forenames')} ${getFromLocalStorage('client_surename')}`,style:['left','bigger','bold'],margin:[40,0]},
-            { text:`${aLangKeys[lang]['pro_bikefit']} ${aLangKeys[lang]['pro_head']} ${new Date().toISOString().split('T')[0]}`,style:['left','XXS'],margin:[40,0]}
+            //{ text:`${aLangKeys[lang]['pro_bikefit']} ${aLangKeys[lang]['pro_head']} ${new Date().toISOString().split('T')[0]}`,style:['left','XXS'],margin:[40,0]}
+            { text:`${aLangKeys[lang]['pro_head']} ${Protokolldate}`,style:['left','XXS'],margin:[40,0]}
             
           //  {canvas: [ { type: 'line', x1: 40, y1: 0, x2: 515, y2: 0, lineWidth: 1 } ]}
           //  { text:`${new Date().toISOString().split('T')[0]}`,style:['small','left'],margin:[40,0]}
