@@ -9,7 +9,7 @@ var hockerNormData;
 
 
 var aLangKeys = new Object();
-var lang = "en";
+var lang = "de";
 let reloadTimer = null;
 
 
@@ -30,6 +30,8 @@ let userdata = new Object();
 let products = new Object();
 const imgURL = "https://produkte.velometrik.de/";
 
+var scale_norm=10
+
 
 
 if(ip===""){
@@ -916,10 +918,10 @@ function handleMessage(e) {
     rows = data.n_rows;
     cols = data.n_cols;
     hockerNormData = data.values
-    var upscale = upscaleMatrixWithOffset(hockerNormData, rows, cols, rows * 8, cols * 8, 2);
-    drawHeatmap(upscale, rows * 8, cols * 8, canvas, container, gradient);
+    var upscale = upscaleMatrixWithOffset(hockerNormData, rows, cols, rows * scale_norm, cols * scale_norm, 2);
+    drawHeatmap(upscale, rows * scale_norm, cols * scale_norm, canvas, container, gradient);
     updateChart(hockerNormData, rows, cols); // Neues Chart generieren
-    document.getElementById("images_count").innerHTML = x
+    //document.getElementById("images_count").innerHTML = x
 
   }
 }
@@ -1011,10 +1013,10 @@ function handleMessage2(e) {
     rows = data.n_rows;
     cols = data.n_cols;
     hockerNormData = data.values
-    var upscale = upscaleMatrixWithOffset(hockerNormData, rows, cols, rows * 8, cols * 8, 2);
-    drawHeatmap(upscale, rows * 8, cols * 8, canvas, container, gradient);
+    var upscale = upscaleMatrixWithOffset(hockerNormData, rows, cols, rows * scale_norm, cols * scale_norm, 2);
+    drawHeatmap(upscale, rows * scale_norm, cols * scale_norm, canvas, container, gradient);
     updateChart(hockerNormData, rows, cols); // Neues Chart generieren
-    document.getElementById("images_count").innerHTML = x
+    //document.getElementById("images_count").innerHTML = x
 
   }
 }
