@@ -168,44 +168,61 @@ function end_session(){
  * @param {String[]} array - the array of objects that you want to display
  */
 function clients_list(array) {
-    onsqlresult=getLog;
-    var thead = ['#','Datum der Messung','Name/Vorname','Email']//,'new Session','']
-    var append = $('#clients-list')[0]
-    var container = document.createElement('div')
-    container.classList.add('uk-container','uk-padding-remove')
-    append.append(container)
-    var table = document.createElement('table')
-    table.classList.add('uk-table','uk-table-middle','uk-table-divider','uk-table-hover')
+    const lang = localStorage.getItem('lang');
+    onsqlresult = getLog;
+    var thead = ['#','Datum der Messung','Name/Vorname','Email'];
+    var append = $('#clients-list')[0];
+    var container = document.createElement('div');
+    container.classList.add('uk-container','uk-padding-remove');
+    append.append(container);
+
+    var table = document.createElement('table');
+    table.classList.add('uk-table','uk-table-middle','uk-table-divider','uk-table-hover');
     container.append(table);
-    var table_head= document.createElement('thead')
+
+    var table_head = document.createElement('thead');
     table.append(table_head);
     var tr_head = document.createElement('tr');
     table_head.append(tr_head);
     thead.forEach(element => {
         var head = document.createElement('th');
-        head.setAttribute('key',element)
-        head.innerHTML = element
+        head.setAttribute('key',element);
+        head.innerHTML = element;
         tr_head.append(head);
-    })
+    });
+
     var tbody = document.createElement('tbody');
     table.append(tbody);
 
-    array.forEach(element => {
-        var x = new Object;
-        x = element;
+    array.forEach(x => {
+        // --- einfache Formatierung des Datums ---
+        let date = x.first_contact || '';
+        if (lang === 'de' && date) {
+            // z.B. '2025-10-21' oder '2025-05-13 08:08:55'
+            const parts = date.split(' ');
+            const d = parts[0].split('-'); // [YYYY,MM,DD]
+            if (d.length === 3) {
+                date = `${d[2]}.${d[1]}.${d[0]}`;
+            }
+            if (parts[1]) date += ' ' + parts[1]; // Zeit anhängen, falls vorhanden
+        }
+
         var tr_body = document.createElement('tr');
-        tr_body.classList.add('suche')
-        tr_body.setAttribute('suche',`${x.surname||""} ${x.forename||""} ${x.first_contact} ${x.email||""}`)
+        tr_body.classList.add('suche');
+        tr_body.setAttribute('suche',`${x.surname||""} ${x.forename||""} ${x.first_contact} ${x.email||""}`);
         tbody.append(tr_body);
-        tr_body.innerHTML =  `<td onclick="info(${x.client_id},'${x.surname||""} ${x.forename||""}','${x.forename||""}','${x.surname||""}','${x.email||""}','${x.first_contact}')">${x.client_id}</td>`
-        tr_body.innerHTML += `<td onclick="info(${x.client_id},'${x.surname||""} ${x.forename||""}','${x.forename||""}','${x.surname||""}','${x.email||""}','${x.first_contact}')">${x.first_contact}</td>`
-        tr_body.innerHTML += `<td onclick="info(${x.client_id},'${x.surname||""} ${x.forename||""}','${x.forename||""}','${x.surname||""}','${x.email||""}','${x.first_contact}')">${x.forename||""} ${x.surname||""}</td>`
-        tr_body.innerHTML += `<td onclick="info(${x.client_id},'${x.surname||""} ${x.forename||""}','${x.forename||""}','${x.surname||""}','${x.email||""}','${x.first_contact}')">${x.email||""}</td>`
-        // tr_body.innerHTML += `<td><button class="uk-button uk-button-default uk-button-small" uk-icon="icon: play" onclick="new_session_id(${x.client_id})" uk-tooltip="Neue Sitzung"></button></td>`
-         tr_body.innerHTML += `<td><button class="uk-button uk-button-default uk-button-small adba basicview ico-16 mdi mdi-trash-can-outline" onclick="ClientDel(${x.client_id})"></button></td>`
+
+        const infoCall = `onclick="info(${x.client_id},'${x.surname||""} ${x.forename||""}','${x.forename||""}','${x.surname||""}','${x.email||""}','${x.first_contact}')"`
+
+        tr_body.innerHTML =  `<td ${infoCall}>${x.client_id}</td>`;
+        tr_body.innerHTML += `<td ${infoCall}>${date}</td>`;
+        tr_body.innerHTML += `<td ${infoCall}>${x.forename||""} ${x.surname||""}</td>`;
+        tr_body.innerHTML += `<td ${infoCall}>${x.email||""}</td>`;
+        tr_body.innerHTML += `<td><button class="uk-button uk-button-default uk-button-small adba basicview ico-16 mdi mdi-trash-can-outline" onclick="ClientDel(${x.client_id})"></button></td>`;
     });
+
     ToggleViewMode(getFromLocalStorage("viewmode"));
-    translatejs()
+    translatejs();
 }
 
 /**
