@@ -663,38 +663,87 @@ let comp = setInterval(() => {
     input.click(); // Öffnet den Datei-Dialog
 }
 
-  //SORT AND EDIT CUSTOM PROTOCOL INFORMATIONEN
-  function renderCategoryView() {
-    let container = document.getElementById("costom_protocol_holder");
-    container.innerHTML = "";
+// SORT AND EDIT CUSTOM PROTOCOL INFORMATIONEN
+// SORT AND EDIT CUSTOM PROTOCOL INFORMATIONEN
+function renderCategoryView() {
+  let container = document.getElementById("costom_protocol_holder");
+  container.innerHTML = "";
 
-    let div = newElement({element:"div",attr:[['style','display: flex;align-items: center;justify-content: space-between;']]},container)
-    newElement({ element: "h2", cls: ["uk-modal-title"], attr: [["key", "my_cat"]] }, div).innerHTML = "<!--Cat-->";
-    let div2 = newElement({element:"div"},div)
-    newElement({element:"button",cls:['uk-button','uk-button-primary','mdi','mdi-24px','mdi-download'],attr:[['onclick','DownladCPBackup()']]},div2)
-    newElement({element:"button",cls:['uk-button','uk-button-primary','mdi','mdi-24px','uk-margin-left','mdi-upload'],attr:[['onclick','UploadCPBackup()']]},div2)
-    
-    let divControls = newElement({ element: "div", cls: ["uk-margin"], attr: [["style", "display: flex;justify-content: space-between;align-items: center;align-content: flex-start;flex-direction: row;"]] }, container);
-    newElement({ element: "input", id: "new-category", cls: ["uk-input"], attr: [["key-place", "sys_set_cat_name"]] }, divControls);
-    newElement({ element: "button", cls: ["uk-button", "uk-button-primary", "mdi", "mdi-24px", "mdi-plus-box-outline"], attr: [["onclick", "addCategory()"]] }, divControls);
-    newElement({ element: "button", cls: ["uk-button", "uk-button-secondary", "mdi", "mdi-24px", "mdi-content-save"], attr: [["onclick", "saveCategoryOrder()"]] }, divControls);
-    
-    let ul = newElement({ element: "ul", id: "category-list", cls: ["uk-grid-small", "uk-child-width-1-1"], attr: [["uk-sortable", "handle: .uk-card"], ["uk-grid", ""]] }, container);
-    
-    Object.keys(customJSN).forEach(category => {
-        let li = newElement({ element: "li" }, ul);
-        let div = newElement({ element: "div", cls: ["uk-card", "uk-card-default", "uk-card-body", "uk-text-center", "flex-between"] }, li);
-        newElement({ element: "span", cls: ["uk-sortable-handle"], attr: [["uk-icon", "icon: table"]] }, div);
-        let divButtons = newElement({ element: "div",attr:[['style','display: flex;align-items: center;']] }, div);
-        newElement({ element: "a", attr: [["onclick", `renderFieldView('${category}')`]] }, divButtons).innerHTML = category;
-        newElement({ element: "button", cls: ["uk-button", "uk-button-default", "uk-button-small", "uk-margin-small-right", "mdi", "mdi-24px", "mdi-pencil-box-outline"], attr: [["onclick", `renderFieldView('${category}')`]] }, divButtons);
-        newElement({ element: "button", cls: ["uk-button", "uk-button-error", "uk-button-small", "uk-margin-small-right", "mdi", "mdi-24px", "mdi-trash-can-outline"], attr: [["onclick", `deleteCategory('${category}')`]] }, div);
-    });
+  let div = newElement({element:"div",attr:[['style','display:flex;align-items:center;justify-content:space-between;']]},container);
+  newElement({ element: "h2", cls: ["uk-modal-title"], attr: [["key", "my_cat"]] }, div).innerHTML = "<!--Cat-->";
+  let div2 = newElement({element:"div", attr:[['style','display:flex;align-items:center;gap:.5rem;']]}, div);
 
-    translatejs();
-    setupSortableCategory(); // Event-Listener für Sortierung aktivieren
+  // === Ein Button als Dropdown-Toggle: Text + Icon (alles klickbar) ===
+  const actionsWrap = newElement({ element: "div", cls: ["uk-inline"] }, div2);
+
+  const toggleBtn = newElement({
+    element: "button",
+    cls: ["uk-button","uk-button-default"],
+    attr: [
+      ["type","button"],
+      ["aria-label","Aktionen"],
+      ["title","Aktionen"],
+      ["style","display:flex;align-items:center;padding: 0;"]
+    ]
+  }, actionsWrap);
+
+  // Text links
+  newElement({ element: "span", attr: [["key","sys_import_export"]] }, toggleBtn).innerHTML = "import/export";
+  // Punkte rechts
+  newElement({ element: "span", cls: ["mdi","mdi-dots-vertical","mdi-24px"], attr: [["style","margin-left:auto;"]] }, toggleBtn);
+
+  // Dropdown (per Klick auf den gesamten Button)
+  const dd = newElement({
+    element: "div",
+    attr: [
+      ["uk-dropdown","mode: click; pos: bottom-right;"],
+      ["style","min-width:220px"]
+    ]
+  }, actionsWrap);
+
+  const ulDD = newElement({ element: "ul", cls: ["uk-nav","uk-dropdown-nav"] }, dd);
+
+  // Download
+  const liDown = newElement({ element: "li" }, ulDD);
+  newElement({
+    element: "a",
+    attr: [["onclick","DownladCPBackup()"]], // Hinweis: Tippfehler, s.u.
+    cls: ["uk-flex","uk-flex-middle","gap-sm","mdi","mdi-24px","mdi-download"]
+  }, liDown).innerHTML = '<span class="uk-margin-small-left" key="sys_download_CP">Download CP Backup</span>';
+
+  // Upload
+  const liUp = newElement({ element: "li" }, ulDD);
+  newElement({
+    element: "a",
+    attr: [["onclick","UploadCPBackup()"]],
+    cls: ["uk-flex","uk-flex-middle","gap-sm","mdi","mdi-24px","mdi-upload"]
+  }, liUp).innerHTML = '<span class="uk-margin-small-left" key="sys_upload_CP">Upload CP Backup</span>';
+  // === Ende Actions-Dropdown ===
+
+  let divControls = newElement({ element: "div", cls: ["uk-margin"], attr: [["style", "display:flex;justify-content:space-between;align-items:center;align-content:flex-start;flex-direction:row;"]] }, container);
+  newElement({ element: "input", id: "new-category", cls: ["uk-input"], attr: [["key-place", "sys_set_cat_name"]] }, divControls);
+  newElement({ element: "button", cls: ["uk-button", "uk-button-primary", "mdi", "mdi-24px", "mdi-plus-box-outline"], attr: [["onclick", "addCategory()"]] }, divControls);
+  newElement({ element: "button", cls: ["uk-button", "uk-button-secondary", "mdi", "mdi-24px", "mdi-content-save"], attr: [["onclick", "saveCategoryOrder()"]] }, divControls);
+
+  let ul = newElement({ element: "ul", id: "category-list", cls: ["uk-grid-small", "uk-child-width-1-1"], attr: [["uk-sortable", "handle: .uk-card"], ["uk-grid", ""]] }, container);
+
+  Object.keys(customJSN).forEach(category => {
+    let li = newElement({ element: "li" }, ul);
+    let div = newElement({ element: "div", cls: ["uk-card", "uk-card-default", "uk-card-body", "uk-text-center", "flex-between"] }, li);
+    newElement({ element: "span", cls: ["uk-sortable-handle"], attr: [["uk-icon", "icon: table"]] }, div);
+    let divButtons = newElement({ element: "div", attr:[['style','display:flex;align-items:center;']] }, div);
+    newElement({ element: "a", attr: [["onclick", `renderFieldView('${category}')`]] }, divButtons).innerHTML = category;
+    newElement({ element: "button", cls: ["uk-button", "uk-button-default", "uk-button-small", "uk-margin-small-right", "mdi", "mdi-24px", "mdi-pencil-box-outline"], attr: [["onclick", `renderFieldView('${category}')`]] }, divButtons);
+    newElement({ element: "button", cls: ["uk-button", "uk-button-error", "uk-button-small", "uk-margin-small-right", "mdi", "mdi-24px", "mdi-trash-can-outline"], attr: [["onclick", `deleteCategory('${category}')`]] }, div);
+  });
+
+  translatejs();
+  setupSortableCategory();
 }
 
+
+
+
 function renderFieldView(category) {
     let container = document.getElementById("costom_protocol_holder");
     container.innerHTML = "";
